@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2024  Metrum Research Group
+# Copyright (C) 2013 - 2025  Metrum Research Group
 #
 # This file is part of mrgsolve.
 #
@@ -338,25 +338,29 @@ cumoffset <- function(x) {
   ans
 }
 
-##' Operations with matlist objects
-##' 
-##' @param x a matlist object
-##' @param ... other matlist objects
-##' @param recursive not used
-##' @rdname matlist_ops
-##' @export
-setMethod("c", "matlist", function(x,...,recursive=FALSE) {
-  what <- c(list(x), list(...))
-  stopifnot(all(sapply(what, is.matlist)))
-  what <- what[sapply(what, slot, name = "n") > 0]
-  if(length(what)==1) return(x)
-  d <- lapply(what, as.matrix)
-  d <- setNames(d, sapply(what, names))
-  l <- sapply(unname(what), labels)
-  create_matlist(d, labels = l, class = class(x)[1])
+#' Operations with matlist objects
+#' 
+#' @param x a matlist object.
+#' @param ... other matlist objects.
+#' @param recursive not used.
+#' @rdname matlist_ops
+#' @export
+setMethod("c", "matlist", function(x, ..., recursive = FALSE) {
+  cl <- class(x)[1]
+  x <- c(list(x), list(...))
+  stopifnot(all(sapply(x, is.matlist)))
+  nonzero <- sapply(x, slot, name = "n") > 0
+  if(!any(nonzero)) {
+    return(NULL)
+  }
+  if(sum(nonzero)==1) return(x[[which(nonzero)]])
+  x <- x[nonzero]
+  data <- lapply(x, as.matrix)
+  data <- setNames(data, sapply(x, names))
+  lbls <- sapply(unname(x), labels)
+  create_matlist(data, labels = lbls, class = cl)
 })
 
-
 #' Collapse OMEGA or SIGMA matrix lists
 #' 
 #' If multiple `OMEGA` (or `SIGMA`) blocks were written into the model, 
