@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2021  Metrum Research Group
+# Copyright (C) 2013 - 2024  Metrum Research Group
 #
 # This file is part of mrgsolve.
 #
@@ -16,51 +16,55 @@
 # along with mrgsolve.  If not, see <http://www.gnu.org/licenses/>.
 
 
-##' Internal model library
-##' 
-##' @param model \code{character} name of a model in the library
-##' @param ... passed to \code{\link{mread_cache}}
-##' @param list list available models
-##' @export
-##' 
-##' @details
-##' See \code{\link{modlib_details}}, \code{\link{modlib_pk}}, 
-##' \code{\link{modlib_pkpd}}, 
-##' \code{\link{modlib_tmdd}}, \code{\link{modlib_viral}} for details.
-##' 
-##' Call \code{modlib("<modelname>")} to compile and load a mode from the 
-##' library.
-##' 
-##' Call \code{modlib(list=TRUE)} to list available models.  Once the model 
-##' is loaded (see examples below), call \code{as.list(mod)$code} to see
-##' model code and equations.
-##' 
-##' 
-##' @examples
-##' \dontrun{
-##' mod <- mread("pk1cmt", modlib())
-##' mod <- mread("pk2cmt", modlib()) 
-##' mod <- mread("pk3cmt", modlib()) 
-##' mod <- mread("pk1",    modlib())
-##' mod <- mread("pk2",    modlib())
-##' mod <- mread("popex",  modlib())
-##' mod <- mread("irm1",   modlib()) 
-##' mod <- mread("irm2",   modlib()) 
-##' mod <- mread("irm3",   modlib()) 
-##' mod <- mread("irm4",   modlib())
-##' mod <- mread("emax",   modlib())
-##' mod <- mread("effect", modlib())
-##' mod <- mread("tmdd",   modlib())
-##' mod <- mread("viral1", modlib())
-##' mod <- mread("viral2", modlib())
-##' mod <- mread("pred1",  modlib())
-##' mod <- mread("pbpk",   modlib())
-##' mod <- mread("1005",   modlib())      # embedded NONMEM result
-##' mod <- mread("nm-like", modlib()) # model with nonmem-like syntax
-##' 
-##' mrgsolve:::code(mod)
-##' }
-##' 
+#' Internal model library
+#' 
+#' Pre-coded models are included in the mrgsolve installation; these can be 
+#' compiled and loaded with `modlib()`. These models are usually most useful 
+#' for exploratory simulation or learning mrgsolve. Production simulation work 
+#' is typically accomplished by a custom-coded model.
+#' 
+#' @param model `character` name of a model in the library.
+#' @param ... passed to [mread_cache()].
+#' @param list logical; if `TRUE`, a list of available models is returned.
+#' 
+#' @details
+#' See [modlib_details], [modlib_pk], [modlib_pkpd], [modlib_tmdd], 
+#' [modlib_viral] for details.
+#' 
+#' Call `modlib("<modelname>")` to compile and load a mode from the 
+#' library.
+#' 
+#' Call `modlib(list=TRUE)` to list available models.  Once the model 
+#' is loaded (see examples below), call `as.list(mod)$code` to extract
+#' model code and equations.
+#' 
+#' @examples
+#' \dontrun{
+#' mod <- mread("pk1cmt", modlib())
+#' mod <- mread("pk2cmt", modlib()) 
+#' mod <- mread("pk3cmt", modlib()) 
+#' mod <- mread("pk1",    modlib())
+#' mod <- mread("pk2",    modlib())
+#' mod <- mread("popex",  modlib())
+#' mod <- mread("irm1",   modlib()) 
+#' mod <- mread("irm2",   modlib()) 
+#' mod <- mread("irm3",   modlib()) 
+#' mod <- mread("irm4",   modlib())
+#' mod <- mread("emax",   modlib())
+#' mod <- mread("effect", modlib())
+#' mod <- mread("tmdd",   modlib())
+#' mod <- mread("viral1", modlib())
+#' mod <- mread("viral2", modlib())
+#' mod <- mread("pred1",  modlib())
+#' mod <- mread("pbpk",   modlib())
+#' mod <- mread("1005",   modlib())  # embedded NONMEM result
+#' mod <- mread("nm-like", modlib()) # model with nonmem-like syntax
+#' mod <- mread("evtools", modlib())
+#' 
+#' as.list(mod)$code
+#' }
+#' @md
+#' @export
 modlib <- function(model = NULL,...,list=FALSE)  {
   if(list) {
     return(modlib_list())
@@ -75,7 +79,7 @@ modlib <- function(model = NULL,...,list=FALSE)  {
 modlib_models <- c(
   "pk1cmt", "pk2cmt", "pk3cmt", "pk", "pk1", "pk2", "popex",
   "irm1", "irm2", "irm3", "pred1", "emax", "tmdd", "viral1", 
-  "viral2", "effect", "1005", "nm-like"
+  "viral2", "effect", "1005", "nm-like", "evtools"
 )
 #nocov end
 
@@ -302,21 +306,24 @@ NULL
 NULL
 
 
-##' Extract the code from a model
-##' 
-##' This function is currently not exported, so be sure to call it with 
-##' `mrgsolve:::code(...)`.
-##' 
-##' @param x an mrgsolve model object
-##' 
-##' @examples
-##' mod <- mrgsolve::house()
-##' mrgsolve:::code(mod)
-##' 
-##' @return 
-##' A character vector of model code.
-##' 
-##' @md
+#' Extract the code from a model
+#' 
+#' This function is currently not exported, so be sure to call it with 
+#' `mrgsolve:::code(...)`.
+#' 
+#' @param x a model object.
+#' 
+#' @examples
+#' mod <- mrgsolve::house()
+#' mrgsolve:::code(mod)
+#' 
+#' # Alternative
+#' as.list(mod)$code
+#' 
+#' @return 
+#' A character vector of model code.
+#' 
+#' @md
 code <- function(x) {
   stopifnot(is.mrgmod(x))
   what <- try(x@code, silent=TRUE)
