@@ -86,6 +86,8 @@ typedef double capture;
 #define CMT self.cmt
 // Bool flag indicating that the system is advancing to steady-state
 #define SS_ADVANCE _ss_flag_
+// Bool flag indicating that an infusion is ending
+#define END_OF_INFUSION (self.evid==9)
 // Always accept THETA(n) as THETAn
 #define THETA(a) THETA##a
 
