@@ -31,6 +31,39 @@ void LSODA::mxhnil_(const int value) {
   if(value!=0) iopt = 1;
 }
 
+void LSODA::setup_tol_vectors(const Rcpp::S4& mod) {
+  Rcpp::NumericVector xatol_ = Rcpp::as<Rcpp::NumericVector>(mod.slot("vec_atol"));
+  Rcpp::NumericVector xrtol_ = Rcpp::as<Rcpp::NumericVector>(mod.slot("vec_rtol"));
+  bool size_error = false;
+  if(xatol_.size() != Neq) {
+    std::string size = std::to_string(xatol_.size());
+    std::string expect = std::to_string(Neq);
+    Rcpp::CharacterVector text = 
+      "[lsoda] expecting atol vector with size " + expect + ", but got size " + size + ".";
+    Rcpp::message(text);
+    size_error = true;
+  }
+  if(xrtol_.size() != Neq) {
+    std::string size = std::to_string(xrtol_.size());
+    std::string expect = std::to_string(Neq);
+    Rcpp::CharacterVector text = 
+      "[lsoda] expecting rtol vector with size " + expect + ", but got size " + size + ".";
+    Rcpp::message(text);
+    size_error = true;
+  }
+  if(size_error) {
+    Rcpp::stop("itol is > 1, but atol/rtol vector(s) are not the expected size.");
+  }
+  // initialize to the default
+  atol_.assign(Neq+1,1e-8);
+  rtol_.assign(Neq+1,1e-8);
+  for(size_t i = 0; i < Neq; ++i) {
+    // tolerances in the solver object start at index 1
+    atol_[i+1] = xatol_[i]; 
+    rtol_[i+1] = xrtol_[i];
+  }
+}
+
 bool LSODA::abs_compare(double a, double b)
 {
     return (std::abs(a) < std::abs(b));
@@ -647,7 +680,7 @@ void LSODA::stoda(const size_t neq, vector<double> &y, LSODA_ODE_SYSTEM_TYPE f,
 
 void LSODA::ewset(const vector<double> &ycur)
 {
-    switch (itol_)
+    switch (itol)
     {
     case 1:
         for (size_t i = 1; i <= n; ++i)
