@@ -759,3 +759,24 @@ test_that("Skip cpp dot check gh-1159", {
   
   expect_s4_class(mcode("cpp-dot-skip-4", code, compile = FALSE), "mrgmod")
 })
+
+test_that("Invalid item in $SET generates error", {
+  code <- "$SET end = 25, kyle = 2"
+  expect_error(
+    mcode("dollar-set-item-check-1", code),
+    "The $SET block cannot handle this item", 
+    fixed = TRUE
+  )
+  code <- "$SET end = 25, kyle = 2, zip = 55455"
+  expect_error(
+    mcode("dollar-set-item-check-2", code),
+    "The $SET block cannot handle these items", 
+    fixed = TRUE
+  )
+  code <- "$SET a = 2"  # ambiguous partial match
+  expect_error(
+    mcode("dollar-set-item-check-3", code),
+    "The $SET block cannot handle this item",
+    fixed = TRUE
+  )
+})
